PrayerTimeHelper class

Prayer times calculation helper

Constructors

PrayerTimeHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getRecommendedFastingDays(int month) → List<int>
Gets the recommended fasting days in a month
isRecommendedFastingDay(HijriDate date) → bool
Checks if a date falls on a recommended fasting day