HorizontalWeekCalendar class

Inheritance

Constructors

HorizontalWeekCalendar({Key? key, dynamic onDateChange(DateTime)?, dynamic onWeekChange(List<DateTime>)?, Color? activeBackgroundColor, HorizontalWeekCalenderController? controller, Color? inactiveBackgroundColor, Color? disabledBackgroundColor = Colors.grey, Color? activeTextColor = Colors.white, Color? inactiveTextColor = Colors.white, Color? disabledTextColor = Colors.white, Color? activeNavigatorColor, Color? inactiveNavigatorColor, Color? monthColor, WeekStartFrom? weekStartFrom = WeekStartFrom.monday, BorderRadiusGeometry? borderRadius = const BorderRadius.all(Radius.circular(8)), ScrollPhysics? scrollPhysics = const ClampingScrollPhysics(), bool? showNavigationButtons = true, String? monthFormat, required DateTime minDate, required DateTime maxDate, required DateTime initialDate, bool showTopNavbar = true, double? carouselHeight, double? itemMarginHorizontal, Color? itemBorderColor, bool translateNumbers = false, String languageCode = 'en', List<String>? customDayNames, List<String>? customMonthNames, TextStyle? dayTextStyle, TextStyle? dayNameTextStyle, TextStyle? monthTextStyle, bool showGregorianUnderHijri = false, String gregorianDayFormat = 'd', TextStyle? gregorianDayTextStyle, double gregorianDayOpacity = 0.6, bool useHijriDates = false, HijriDate? hijriMinDate, HijriDate? hijriMaxDate, HijriDate? hijriInitialDate})
controll the date jump

Properties

activeBackgroundColor Color?
Active background color
final
activeNavigatorColor Color?
Active Navigator color
final
activeTextColor Color?
Active text color
final
borderRadius BorderRadiusGeometry?
border radius of date card
final
carouselHeight double?
final
controller HorizontalWeekCalenderController?
final
customDayNames List<String>?
Custom day names starting from Sunday Must contain exactly 7 names: Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday If null, default Arabic names will be used Example: 'Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'
final
customMonthNames List<String>?
Custom month names for Hijri calendar starting from Muharram Must contain exactly 12 names: Muharram, Safar, Rabi' al-awwal, ... If null, default Arabic names will be used
final
dayNameTextStyle TextStyle?
Text style for day names (Sun, Mon, etc.)
final
dayTextStyle TextStyle?
Text style for day numbers
final
disabledBackgroundColor Color?
Disable background color
final
disabledTextColor Color?
Disable text color
final
gregorianDayFormat String
Gregorian day format when showGregorianUnderHijri is true
final
gregorianDayOpacity double
Opacity applied to the Gregorian day text
final
gregorianDayTextStyle TextStyle?
Text style for the Gregorian day under Hijri
final
hashCode int
The hash code for this object.
no setterinherited
hijriInitialDate HijriDate?
Initial Hijri date to be selected (only used when useHijriDates is true)
final
hijriMaxDate HijriDate?
Maximum Hijri date for the calendar (only used when useHijriDates is true)
final
hijriMinDate HijriDate?
Minimum Hijri date for the calendar (only used when useHijriDates is true)
final
inactiveBackgroundColor Color?
In-Active background color
final
inactiveNavigatorColor Color?
In-Active Navigator color
final
inactiveTextColor Color?
In-Active text color
final
initialDate DateTime
final
itemBorderColor Color?
final
itemMarginHorizontal double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
languageCode String
Language code for number translation
final
maxDate DateTime
final
minDate DateTime
final
monthColor Color?
Month Color
final
monthFormat String?
monthFormat
final
monthTextStyle TextStyle?
Text style for month display in top navbar
final
onDateChange → dynamic Function(DateTime)?
get DateTime on date select
final
onWeekChange → dynamic Function(List<DateTime>)?
get the list of DateTime on week change
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPhysics ScrollPhysics?
scroll physics
final
showGregorianUnderHijri bool
Whether to show the Gregorian day under the Hijri day
final
showNavigationButtons bool?
showNavigationButtons
final
showTopNavbar bool
final
translateNumbers bool
Whether to translate numbers according to the specified language
final
useHijriDates bool
Whether to use Hijri dates instead of Gregorian dates
final
weekStartFrom WeekStartFrom?
week start from Monday, Sunday, or Friday
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<HorizontalWeekCalendar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited