MoonPhaseWidget class

ويدجت لعرض طور القمر بصريًا باستخدام SVG وقناع هندسي.

Inheritance

Constructors

MoonPhaseWidget({Key? key, required MoonPhaseInfo moonInfo, double size = 160, Color overlayColor = Colors.black, double overlayOpacity = 0, String moonAssetPath = 'assets/moon.svg', String? backgroundAssetPath, String? assetPackage = 'hijri_date', BoxFit fit = BoxFit.contain, bool usePhaseBasedIllumination = false, double moonScale = 0.9})
const

Properties

assetPackage → String?
اسم الحزمة للأصول (افتراضيًا hijri_date)
final
backgroundAssetPath → String?
مسار SVG للخلفية (اختياري)
final
fit → BoxFit
طريقة احتواء الـ SVG
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
moonAssetPath → String
مسار SVG للقمر (قابل للتمرير)
final
moonInfo → MoonPhaseInfo
معلومات طور القمر (يفضّل أخذها من MoonPhaseCalculator أو HijriDate)
final
moonScale → double
نسبة امتلاء دائرة القمر داخل الودجت (0 - 1)
final
overlayColor → Color
لون طبقة الظل فوق القمر
final
overlayOpacity → double
شفافية طبقة الظل (افتراضيًا 0)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double
حجم الودجت (العرض والارتفاع متساويان)
final
usePhaseBasedIllumination → bool
استخدام إضاءة مبنية على الطور بدل القيمة الفعلية
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited