IslamicEvent class

المناسبة الإسلامية

Constructors

IslamicEvent({required int id, required IslamicEventType type, required String titleArabic, required String titleEnglish, required int month, required List<int> days, required bool isReminder, required List<HadithInfo> hadiths})
const

Properties

days → List<int>
final
hadiths → List<HadithInfo>
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
isReminder → bool
final
month → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
titleArabic → String
final
titleEnglish → String
final
type → IslamicEventType
final

Methods

daysUntilEvent() → int
حساب الأيام المتبقية للمناسبة
getTitle([String language = 'ar']) → String
الحصول على العنوان حسب اللغة
isThisMonth() → bool
التحقق من كون المناسبة في الشهر الحالي
isToday() → bool
التحقق من كون اليوم هو يوم المناسبة
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited